@@ -1,7 +1,7 @@
 traceGeneProfiles <-
 function(targetData, parentData, dataDescription=NULL,
-			    targetColor = "#046380", 
-			    parentColor = "#8E3557", onepage=TRUE)
+			    targetColor = "grey", 
+			    parentColor = "blue", onepage=TRUE)
 {
   # In case of repeted measurements
   if(!is.null(dataDescription)){  
