@@ -1,5 +1,5 @@
 traceNetworks <-
-function(ARTIVAnet, edgesThreshold, parentColor = "#8E3557", targetColor = "#046380", parentgeneNames = TRUE, targetgeneNames = TRUE, layout = "fruchterman.reingold", onepage=TRUE)
+function(ARTIVAnet, edgesThreshold, parentColor = "blue", targetColor = "grey", parentgeneNames = TRUE, targetgeneNames = TRUE, layout = "fruchterman.reingold", onepage = TRUE)
 {
   # Input parameters:
   # ARTIVAnet: is a data frame with the results obtained after an ARTIVA
@@ -58,6 +58,68 @@ function(ARTIVAnet, edgesThreshold, parentColor = "#8E3557", targetColor = "#046
   SubNetwork = delete.edges(GlobalNetwork, E(GlobalNetwork)[EdgesToDelete - 1])
   # Note that indice in the vector E(g) start at 0
 
+
+########################################################################
+#Modified: 02/17/2012
+#Last modification: 03/16/2012
+#By SERVILLO David
+########################################################################
+#***************************************************************************************************
+  # Names of the nodes represented in the graph.
+	NodeLabel  = get.vertex.attribute(GlobalNetwork, name = "name")
+
+	#Declare and initialize intervals of parent genes and target genes
+	intervalParent = 0
+	intervalTarget = 0
+
+	SizeParent = 20
+	SizeTarget = 10
+
+	NodeCoord = NULL
+  # Nodes coordinates are calculated according to the global structure of the graph
+	if(layout == "geneLines")   #The user did not specify the layout
+	{
+
+		#The space beetwen vertices on the same line are calculated
+		intervalParent = 2/(length(parentGeneList) - 1)
+		intervalTarget = 2/(length(targetGeneList) - 1)
+		xParent = -1
+		xTarget = -1
+		for(i in 1:length(NodeLabel))
+		{
+			if(sum(parentGeneList == NodeLabel[i]) > 0)   #Parent genes are drawn in a line at the top of the graphical interface
+			{
+				if(length(parentGeneList) == 1)
+					NodeCoord=rbind(NodeCoord, c(0, 0.8))
+				else
+				{
+					NodeCoord=rbind(NodeCoord, c(xParent, 0.8))
+					xParent = xParent + intervalParent
+				}
+			}
+			else if(sum(targetGeneList == NodeLabel[i]) > 0)   #Target genes are drawn in a line at the bottom of the graphical interface
+			{
+				if(length(targetGeneList) == 1)
+				{
+					NodeCoord=rbind(NodeCoord, c(0, 0.2))
+				}
+				else
+				{
+					NodeCoord=rbind(NodeCoord, c(xTarget, 0.2))
+					xTarget = xTarget + intervalTarget
+				}
+			}
+		}
+	#The size of the vertices are reduced if the interval is too low
+	if(intervalParent < 0.2)
+	{SizeParent = 210/length(parentGeneList)}
+	if(intervalTarget < 0.1)
+	{SizeTarget = 200/length(targetGeneList)}
+
+    # end of plot with geneLines()
+	}
+
+
   # Nodes coordinates are calculated according to the global structure of the graph  
   if(layout == "fruchterman.reingold")
   {
@@ -106,44 +168,74 @@ function(ARTIVAnet, edgesThreshold, parentColor = "#8E3557", targetColor = "#046
   # Vectors to store different information for the graphical representation
   NodeSize = NULL
   NodeColor = NULL
-  LabelPos = NULL
+  #LabelPos = NULL
   
   # Labels of the nodes to be written
   WritenNodeLabel = NodeLabel
 
   #To adapt the size of the nodes to the number of genes
-  if(GeneNumber < 100)
-  {
-    Size = 11 - round(GeneNumber * 10 / 100)
-  }
+#  if(GeneNumber < 100)
+#  {
+#    Size = 11 - round(GeneNumber * 10 / 100)
+#  }
   
-  if(GeneNumber >= 100)
-  {
-    Size = 1
-  }
+#  if(GeneNumber >= 100)
+#  {
+#    Size = 1
+#  }
+ 
+#  for(i in 1:length(NodeLabel))
+#  {
+    ## If the node is a parent gene
+#    if(sum(parentGeneList == NodeLabel[i]) > 0)
+#      {
+#        NodeSize = c(NodeSize, 2 * Size)	
+ #       NodeColor = c(NodeColor, parentColor)
+        #LabelPos = c(LabelPos, (2 * Size)/15)
+ #       if(parentgeneNames == FALSE)
+ #         {WritenNodeLabel[i] = ""}			
+ #     }else{       
+        ## If the node is a target gene
+ #       if(sum(targetGeneList == NodeLabel[i]) > 0)
+ #         {
+ #           NodeSize = c(NodeSize, Size)
+ #           NodeColor  = c(NodeColor, targetColor)
+            #LabelPos = c(LabelPos, (2 * Size)/15)
+ #           if(targetgeneNames == FALSE)
+ #             {WritenNodeLabel[i] = ""}			
+ #         }
+ #     }
+ # }
+
+########################################################################
+#Modified: 02/24/2012
+#Last modification: 02/24/2012
+#By SERVILLO David
+########################################################################
+#***************************************************************************************************
  
   for(i in 1:length(NodeLabel))
   {
     ## If the node is a parent gene
     if(sum(parentGeneList == NodeLabel[i]) > 0)
       {
-        NodeSize = c(NodeSize, 2 * Size)	
+	NodeSize = c(NodeSize, SizeParent)
         NodeColor = c(NodeColor, parentColor)
-        LabelPos = c(LabelPos, (2 * Size)/15)
-        if(parentgeneNames == FALSE)
+	        if(parentgeneNames == FALSE)
           {WritenNodeLabel[i] = ""}			
-      }else{       
+      }else{
         ## If the node is a target gene
         if(sum(targetGeneList == NodeLabel[i]) > 0)
           {
-            NodeSize = c(NodeSize, Size)
-            NodeColor  = c(NodeColor, targetColor)
-            LabelPos = c(LabelPos, (2 * Size)/15)
+	    NodeSize = c(NodeSize, SizeTarget)
+            NodeColor = c(NodeColor, targetColor)
             if(targetgeneNames == FALSE)
               {WritenNodeLabel[i] = ""}			
+
           }
       }
   }
+#***************************************************************************************************
 
   ## One subnetwork is traced for each different CPstart in the data
   CPstartList = sort(unique(ARTIVAnet$CPstart))
@@ -175,7 +267,7 @@ function(ARTIVAnet, edgesThreshold, parentColor = "#8E3557", targetColor = "#046
           MainTitle = paste("Sub-network #", i,"\n( time point", CurrentCPstart, "to ", CPstartList[i+1] - 1, ")") 
   	}
 
-      PlotFunction(SubNetwork, NodeSize, NodeColor, WritenNodeLabel, LabelPos, NodeCoord, MainTitle)  
+      PlotFunction(SubNetwork, NodeSize, NodeColor, WritenNodeLabel, LabelPos = 0, NodeCoord, MainTitle)  
       if(!onepage | i==1){
         legend(par("usr")[1],par("usr")[3],c("Positive interaction", "Negative interaction"),lty= c(1,2))
       } 	
